from setuptools import setup

setup(name='wsi_prob_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['wsi_prob_distributions'],
      author = 'Walid Ismail',
      zip_safe=False)
